@@ -83,7 +83,6 @@ typedef struct {
   GFile *	    file;
   GFileInputStream *stream;
   GVfsJob *	    job;
-  GVfsBackendArchive *backend;
   GError *	    error;
   guchar	    data[4096];
 } GVfsArchive;
@@ -157,9 +156,8 @@ gvfs_archive_close (struct archive *archive,
   GVfsArchive *d = data;
 
   DEBUG ("CLOSE\n");
-  if (!d->stream)
-    g_vfs_backend_force_unmount (G_VFS_BACKEND (d->backend));
-  g_clear_object (&d->stream);
+  g_object_unref (d->stream);
+  d->stream = NULL;
   return ARCHIVE_OK;
 }
 
@@ -171,10 +169,10 @@ gvfs_archive_set_error_from_errno (GVfsArchive *archive)
   if (gvfs_archive_in_error (archive))
     return;
 
-  g_set_error_literal (&archive->error,
-		       G_IO_ERROR,
-		       g_io_error_from_errno (archive_errno (archive->archive)),
-		       archive_error_string (archive->archive));
+  g_vfs_job_failed_literal (archive->job,
+                            G_IO_ERROR,
+                            g_io_error_from_errno (archive_errno (archive->archive)),
+                            archive_error_string (archive->archive));
 }
 
 static void 
@@ -207,7 +205,6 @@ gvfs_archive_finish (GVfsArchive *archive)
 {
   gvfs_archive_pop_job (archive);
 
-  g_object_unref (archive->backend);
   archive_read_free (archive->archive);
   g_slice_free (GVfsArchive, archive);
 }
@@ -220,7 +217,6 @@ gvfs_archive_new (GVfsBackendArchive *ba, GVfsJob *job)
   
   d = g_slice_new0 (GVfsArchive);
 
-  d->backend = g_object_ref (ba);
   d->file = ba->file;
   gvfs_archive_push_job (d, job);
 
@@ -363,6 +359,7 @@ archive_file_set_info_from_entry (ArchiveFile *	        file,
 {
   GFileInfo *info = g_file_info_new ();
   GFileType type;
+  mode_t mode;
   file->info = info;
 
   DEBUG ("setting up %s (%s)\n", archive_entry_pathname (entry), file->name);
@@ -417,10 +414,13 @@ archive_file_set_info_from_entry (ArchiveFile *	        file,
   g_file_info_set_size (info,
 			archive_entry_size (entry));
 
+  mode = archive_entry_perm (entry);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_READ, TRUE);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, FALSE);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE, FALSE);
-  g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE, type == G_FILE_TYPE_DIRECTORY);
+  g_file_info_set_attribute_boolean (info,
+                                     G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE,
+                                     type == G_FILE_TYPE_DIRECTORY || mode & S_IXUSR);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_TRASH, FALSE);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_RENAME, FALSE);
 
@@ -440,7 +440,6 @@ const char		*archive_entry_fflags_text(struct archive_entry *);
 gid_t			 archive_entry_gid(struct archive_entry *);
 const char		*archive_entry_gname(struct archive_entry *);
 const char		*archive_entry_hardlink(struct archive_entry *);
-mode_t			 archive_entry_mode(struct archive_entry *);
 unsigned int		 archive_entry_nlink(struct archive_entry *);
 dev_t			 archive_entry_rdev(struct archive_entry *);
 dev_t			 archive_entry_rdevmajor(struct archive_entry *);
